# Croupier

Croupier library support rand select items from list with difference algo.

## Installation

```shell
pip install pycrouiper
```

## Usage

Just like this:

```
>>> import pycroupier
>>> damping = pycroupier.damping()
>>> data = ["b", "e", "h", "d", "f"]
>>> damping.draw(data, 2)

```
